/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: context.c 8 2005-09-23 18:55:21Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include "context_p.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>


CC_CONTEXT *CC_Context_new(unsigned short ctn,
                           unsigned short port) {
  CC_CONTEXT *ctx;

  ctx=(CC_CONTEXT*)malloc(sizeof(CC_CONTEXT));
  memset((void*)ctx, 0, sizeof(CC_CONTEXT));
  ctx->ctn=ctn;
  ctx->port=port;

  return ctx;
}



void CC_Context_free(CC_CONTEXT *ctx) {
  if (ctx) {
    if (ctx->data)
      free(ctx->data);
    free(ctx);
  }
}



unsigned short CC_Context_GetCtn(const CC_CONTEXT *ctx) {
  assert(ctx);
  return ctx->ctn;
}



unsigned short CC_Context_GetPort(const CC_CONTEXT *ctx) {
  assert(ctx);
  return ctx->port;
}



void CC_Context_Add(CC_CONTEXT **head, CC_CONTEXT *ctx) {
  CC_CONTEXT *curr;

  assert(ctx);
  assert(head);

  curr=*head;
  if (!curr) {
    *head=ctx;
  }
  else {
    while(curr->next) {
      curr=curr->next;
    }
    curr->next=ctx;
  }
}



void CC_Context_Del(CC_CONTEXT **head, CC_CONTEXT *ctx) {
  CC_CONTEXT *curr;

  assert(ctx);
  assert(head);
  curr=*head;
  if (curr) {
    if (curr==ctx) {
      *head=curr->next;
    }
    else {
      while(curr->next!=ctx) {
        curr=curr->next;
      }
      if (curr)
        curr->next=ctx->next;
    }
  }
  ctx->next=0;
}



CC_CONTEXT *CC_Context_Next(const CC_CONTEXT *ctx) {
  assert(ctx);
  return ctx->next;
}



const unsigned char *CC_Context_GetDataPtr(const CC_CONTEXT *ctx) {
  assert(ctx);
  return ctx->data;
}



unsigned int CC_Context_GetDataLen(const CC_CONTEXT *ctx) {
  assert(ctx);
  return ctx->dataLen;
}



void CC_Context_SetData(CC_CONTEXT *ctx,
                        const unsigned char *p,
                        unsigned int plen) {
  assert(ctx);
  if (ctx->data)
    free(ctx->data);
  if (p && plen) {
    ctx->data=(unsigned char*)malloc(plen);
    assert(ctx->data);
    memmove(ctx->data, p, plen);
    ctx->dataLen=plen;
  }
  else {
    ctx->data=0;
    ctx->dataLen=0;
  }
}



int CC_Context_GetReportAbsence(const CC_CONTEXT *ctx) {
  assert(ctx);
  return ctx->reportAbsence;
}



void CC_Context_SetReportAbsence(CC_CONTEXT *ctx, int i) {
  assert(ctx);
  ctx->reportAbsence=i;
}








