/**************************
 $RCSfile$
 -------------------
 cvs         : $Id: kbd_handler.h 17 2005-11-29 18:26:56Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef KBD_HANDLER_H
#define KBD_HANDLER_H

#include <linux/input.h>

typedef struct KBD_HANDLER KBD_HANDLER;


#define KBD_HANDLER_OK      0
#define KBD_HANDLER_NO_CARD 1
#define KBD_HANDLER_ERROR_ABORTED          (-1)
#define KBD_HANDLER_ERROR_BUFFER_TOO_SMALL (-2)
#define KBD_HANDLER_ERROR_CARD_SKIPPED     (-3)

#define KBD_HANDLER_MAXDATA                 512
#define KBD_HANDLER_CARD_LINES 16

typedef int (*KBD_HANDLER_INIT_FN)(KBD_HANDLER *kh);
typedef void (*KBD_HANDLER_CLOSE_FN)(KBD_HANDLER *kh);
typedef int (*KBD_HANDLER_HANDLE_FN)(KBD_HANDLER *kh);

typedef int (*KBD_HANDLER_GET_CARD_FN)(KBD_HANDLER *kh,
                                       unsigned char *buffer,
                                       unsigned int *bufsize);
typedef void (*KBD_HANDLER_FREE_PRIVATE_DATA_FN)(KBD_HANDLER *kh,
                                                 void *p);

KBD_HANDLER *kbd_handler_new();
void kbd_handler_free(KBD_HANDLER *kh);
void kbd_handler_set_private_data(KBD_HANDLER *kh, void *p,
                                  KBD_HANDLER_FREE_PRIVATE_DATA_FN fn);
void *kbd_handler_get_private_data(KBD_HANDLER *kh);

void kbd_handler_set_init_fn(KBD_HANDLER *kh,
                             KBD_HANDLER_INIT_FN fn);
void kbd_handler_set_close_fn(KBD_HANDLER *kh,
                              KBD_HANDLER_CLOSE_FN fn);
void kbd_handler_set_handle_fn(KBD_HANDLER *kh,
                               KBD_HANDLER_HANDLE_FN fn);
void kbd_handler_set_get_card_fn(KBD_HANDLER *kh,
                                 KBD_HANDLER_GET_CARD_FN fn);

int kbd_handler_make_card_data(KBD_HANDLER *kh,
                               const unsigned char *ibuf,
                               unsigned int ilen,
                               unsigned char *buffer,
                               unsigned int *buflen);

int kbd_handler_input_wait(KBD_HANDLER *kh, int ms, int outfd);



int kbd_handler_init(KBD_HANDLER *kh);
void kbd_handler_close(KBD_HANDLER *kh);
int kbd_handler_handle(KBD_HANDLER *kh);

int kbd_handler_get_card(KBD_HANDLER *kh,
                         unsigned char *buffer,
                         unsigned int *bufsize);




#endif

