/***************************************************************************
 * $RCSfile$
 -------------------
 cvs         : $Id: cherry.c 16 2005-11-29 18:25:58Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de
 *
 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef __KERNEL__
#define __KERNEL__
#endif

#ifdef MODVERSIONS
#include <linux/modversions.h>
#endif

#include <linux/input.h>
#include <linux/module.h>
#include <linux/sched.h>
#include <linux/input.h>
#include <linux/fs.h>
#include <asm/uaccess.h>


//#define DEBUG_MSGS

#define CHERRY_MAJOR 56

#define CHERRY_MAXEVENTS 2048
#define CHERRY_MAXDATA    512
#define CHERRY_CARD_LINES 16
#define CHERRY_KEY_TIMEOUT_MS 500

#define DRIVER_DESC "Cherry Keyboard Card Reader Driver"
#define DEVICE_DESC "Cherry Keyboard Card Reader"

MODULE_AUTHOR("Martin Preuss <martin@libchipcard.de>");
MODULE_DESCRIPTION(DRIVER_DESC);
MODULE_LICENSE("GPL");

static int major=CHERRY_MAJOR;
module_param(major, int, 0);
MODULE_PARM_DESC(major, "device major number to be used by the module");


static struct input_event cherry_event_list[CHERRY_MAXEVENTS];
static int cherry_event_count=0;

static int cherry_aborted=0;
static int cherry_isopen=0;
static int cherry_eof_met=0;

static int cherry_state=0;

static unsigned int cherry_current_buffer=0;
static unsigned char cherry_card_data_ptr[2][CHERRY_MAXDATA];
static unsigned int cherry_card_data_cnt[2]={0,0};

static unsigned long cherry_card_seq_expires=0;

static int cherry_in_card_sequence=0;
static int cherry_in_alt_sequence=0;
static int cherry_ignore_card=0;

static int cherry_lines=0;

static unsigned int cherry_alt_value=0;

DECLARE_WAIT_QUEUE_HEAD(cherry_wait);

static int handler_registered=0;

static struct input_dev *cherry_dev=0;




/* ________________________________________________________________________
 * AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
 *                         Character interpretion
 * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
 */


/* return
 *  0 if key is to be returned,
 *  1 if key is to be filtered,
 * -1 on error */
int cherry_handle_key_in_alt(int keycode, int down){
  if (keycode==KEY_LEFTALT && down==0) {
    cherry_in_alt_sequence=0;

    if (cherry_alt_value==0) {
      /* not an ALT-sequence */
      cherry_in_alt_sequence=0;
      cherry_in_card_sequence=0;
      return 0;
    }

    if (!cherry_ignore_card) {
      if (cherry_card_data_cnt[cherry_current_buffer]>=CHERRY_MAXDATA) {
	printk(KERN_WARNING "cherry: too many bytes received for card\n");
	cherry_ignore_card=1;
      }
      else {
	cherry_card_data_ptr
	  [cherry_current_buffer]
	  [(cherry_card_data_cnt[cherry_current_buffer])++]=
	  (unsigned char)(cherry_alt_value & 0xff);
	if (cherry_alt_value==13) {
	  cherry_lines++;
	}
      }
    }
    return 1;
  }
  else {
    if (down) {
      int i;

      switch(keycode) {
      case KEY_KP1: i=1; break;
      case KEY_KP2: i=2; break;
      case KEY_KP3: i=3; break;
      case KEY_KP4: i=4; break;
      case KEY_KP5: i=5; break;
      case KEY_KP6: i=6; break;
      case KEY_KP7: i=7; break;
      case KEY_KP8: i=8; break;
      case KEY_KP9: i=9; break;
      case KEY_KP0: i=0; break;
      default:      i=-1; break;
      }

      if (i==-1) {
	/* not an ALT-sequence */
	cherry_in_alt_sequence=0;
	cherry_in_card_sequence=0;
	return 0;
      }
      cherry_alt_value*=10;
      cherry_alt_value+=i;
      if (cherry_alt_value > 0xff) {
	printk(KERN_INFO "cherry: value from ALT sequence too high (%x)\n",
	       cherry_alt_value);
	cherry_ignore_card=1;
	return -1;
      }
    } /* if down */
  }
  return 1;
}



/* return
 *  0 if key is to be returned,
 *  1 if key is to be filtered,
 * -1 on error */
int cherry_handle_key_in_card(int keycode, int down){
  if (cherry_in_alt_sequence) {
    int rv;

    rv=cherry_handle_key_in_alt(keycode, down);
    if (rv!=1) {
      return rv;
    }
    if (cherry_lines>=CHERRY_CARD_LINES) {
      /* leave card sequence */
      cherry_in_card_sequence=0;
      cherry_lines=0;

      printk(KERN_INFO "cherry: card data received.\n");

      if (!cherry_ignore_card) {
	unsigned int next_buf;

	next_buf=(cherry_current_buffer + 1) & 1;

	if (cherry_card_data_cnt[next_buf]) {
	  printk(KERN_INFO "cherry: overwriting last card data\n");
	}
	cherry_current_buffer=next_buf;
      }
      cherry_card_data_cnt[cherry_current_buffer]=0;
      cherry_ignore_card=0;
      wake_up(&cherry_wait);
      return 2;
    }
    return 1;
  }
  else {
    if (keycode==KEY_LEFTALT && down!=0) {
      /* enter ALT sequence */
      cherry_in_alt_sequence=1;
      cherry_alt_value=0;
      return 1;
    }
  }

  return 0;
}



int cherry_handle_key(int keycode, int down){
  unsigned long t;

  t=jiffies;

  if (cherry_in_card_sequence) {
    /* check for timeout, adjust it for next key */
    if (t>cherry_card_seq_expires) {
      printk(KERN_WARNING
	     "cherry: Timeout between keys, key assumably not from card reader\n");
      cherry_in_alt_sequence=0;
      cherry_in_card_sequence=0;
      return 0;
    }
    cherry_card_seq_expires=t+CHERRY_KEY_TIMEOUT_MS;
    return cherry_handle_key_in_card(keycode, down);
  }
  else {
    if (keycode==KEY_LEFTALT && down!=0) {
      /* enter card sequence */
      cherry_in_card_sequence=1;
      cherry_card_seq_expires=t+CHERRY_KEY_TIMEOUT_MS;
      cherry_in_alt_sequence=1;
      cherry_ignore_card=0;
      cherry_alt_value=0;
      cherry_lines=0;
      return 1;
    }
  }

  return 0;
}



int cherry_interceptor(int keycode, int down){
  int mask;

  /* check for left ALT key and for rescue key combination */
  switch(keycode){
  case KEY_LEFTSHIFT:  mask=1;  break;
  case KEY_RIGHTSHIFT: mask=2;  break;
  case KEY_LEFTCTRL:   mask=4;  break;
  case KEY_RIGHTCTRL:  mask=8;  break;
  case KEY_ESC:        mask=16; break;
  default:             mask=0;
  }
  if (mask){
    if (down)
      cherry_state |= mask;
    else
      cherry_state &= (~ mask);
  }

  if (cherry_state == 0x1F) { /* all five keys down */
    printk(KERN_INFO
	   "cherry: rescue key combination detected, disabling driver\n");
    cherry_state=0;
    cherry_aborted=1;
    return -1; /* leave event for normal processing */
  }
  else {
    int rv;

    rv=cherry_handle_key(keycode, down);
    if (rv==-1) {
      /* set previous interceptor, this terminates this module */
      printk(KERN_INFO "cherry: driver aborted via handler\n");
      cherry_aborted=1;
      return -1; /* leave event for normal processing */
    }
    return rv;
  }
}








/* ________________________________________________________________________
 * AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
 *                         Input-Device interface
 * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
 */



static int cherry_enqueue_event(struct input_event *ev) {
  if (cherry_event_count>=CHERRY_MAXEVENTS) {
    printk(KERN_INFO "cherry: too many events.\n");
    return -1;
  }
  memmove(&cherry_event_list[cherry_event_count++],
	  ev, sizeof(struct input_event));
  return 0;
}



static void cherry_flush_events(void) {
  int i;

#ifdef DEBUG_MSGS
  printk(KERN_INFO "cherry: flushing events to %s\n",
	 cherry_dev->name);
#endif
  for (i=0; i<cherry_event_count; i++) {
    struct input_event *ev;

    ev=&cherry_event_list[i];

#ifdef DEBUG_MSGS
    printk(KERN_WARNING "cherry: flushing event: %d, %d, %d\n",
	   ev->type, ev->code, ev->value);
#endif
    input_event(cherry_dev, ev->type, ev->code, ev->value);
  }

  cherry_event_count=0;
}



static void cherry__event(struct input_handle *handle,
			  unsigned int event_type,
			  unsigned int event_code,
			  int value){
  struct input_event ev;

  if (event_type==EV_MSC && event_code==MSC_SCAN)
    /* ignore this */
    return;

  memset(&ev, 0, sizeof(ev));
  ev.type=event_type;
  ev.code=event_code;
  ev.value=value;
  if (cherry_enqueue_event(&ev)) {
    printk(KERN_WARNING "cherry: could not enqueue event, aborting\n");
    cherry_flush_events();
    cherry_enqueue_event(&ev);
    cherry_flush_events();
    cherry_aborted=1;
    return;
  }
  if (event_type == EV_KEY) {
    int rv;

    if (cherry_aborted==0)
      rv=cherry_interceptor(event_code, value);
    else
      rv=0;
    if (rv<0) {
      printk(KERN_WARNING "cherry: could not handle event.\n");
      cherry_flush_events();
      cherry_aborted=1;
      return;
    }
    else if (rv==0) {
      cherry_flush_events();
    }
    else if (rv==2) {
      cherry_event_count=0;
    }
  }
}



static void cherry_event(struct input_handle *handle,
			 unsigned int event_type,
			 unsigned int event_code,
			 int value){
  static int inEventHandler=0;

#ifdef DEBUG_MSGS
  printk(KERN_WARNING "cherry: event on %s: %d, %d, %d\n",
	 handle->dev->name, event_type, event_code, value);
#endif
  if (inEventHandler) {
    printk(KERN_WARNING "cherry: recursion detected, aborting\n");
    cherry_aborted=1;
    input_release_device(handle);
  }
  else {
    inEventHandler=1;
    cherry__event(handle, event_type, event_code, value);
    inEventHandler=0;
  }
}



static char cherry_name[] = "cherry";


static struct input_handle *cherry_connect(struct input_handler *handler,
					   struct input_dev *dev,
					   struct input_device_id *id) {
  if (dev && dev->name && id) {
    printk(KERN_INFO "cherry: checking device (%s)\n", dev->name);
    if (strstr(dev->name, "keyboard")!=0) {
      printk(KERN_INFO "cherry: might be a keyboard device (%s)\n",
	     dev->name);
      if ((dev->id.bustype == BUS_I8042) &&
	  (dev->id.vendor == 0x0001) &&
	  (dev->id.product == 0x0001)) {
	struct input_handle *handle;

	printk(KERN_INFO "cherry: found a keyboard device (%s)\n",
	       dev->name);
	if (!(handle = kmalloc(sizeof(struct input_handle), GFP_KERNEL)))
	  return NULL;
	memset(handle, 0, sizeof(struct input_handle));

	handle->dev = dev;
	handle->handler = handler;
	handle->name = cherry_name;

	input_open_device(handle);
	if (input_grab_device(handle)) {
	  printk(KERN_INFO "cherry: could not grab keyboard device (%s)\n",
		 dev->name);
	  input_close_device(handle);
	  kfree(handle);
	  return NULL;
	}
	return handle;
      }
    }
    else {
      printk(KERN_INFO "cherry: not a keyboard device (%s)\n", dev->name);
    }
  }
  else {
    printk(KERN_WARNING "cherry: device with no name or id\n");
  }
  return NULL;
}



static void cherry_disconnect(struct input_handle *handle){
  printk(KERN_INFO "cherry: disconnecting from keyboard device (%s)\n",
	 handle->dev->name);
  input_release_device(handle);
  input_close_device(handle);
  kfree(handle);
}









/* ________________________________________________________________________
 * AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
 *                          File operations
 * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
 */



static int cherry_open(struct inode *in, struct file *f) {
  if (MINOR(in->i_rdev)!=3) {
    printk(KERN_INFO "cherry: only minor 3 is supported.\n");
    return -EINVAL;
  }

  if (cherry_isopen) {
    return -EBUSY;
  }

  if (cherry_aborted) {
    printk(KERN_INFO "cherry: driver aborted.\n");
    return -EINVAL; /* TODO: select better code */
  }

  cherry_isopen++;
  cherry_eof_met=0;

  return 0;
}



static int cherry_close(struct inode *in, struct file *f) {
  cherry_isopen=0;
  cherry_eof_met=0;
  return 0;
}



static ssize_t cherry_read(struct file *f, char *buf,
			   size_t count, loff_t *offs) {
  unsigned int stored_buf;
  unsigned int slen;

  if (!cherry_isopen) {
    return -EINVAL;
  }

  if (cherry_eof_met)
    return 0;

  stored_buf=(cherry_current_buffer + 1) & 1;
  if (cherry_card_data_cnt[stored_buf]==0) {
    if (f->f_flags & O_NONBLOCK)
      return -EAGAIN;
    interruptible_sleep_on(&cherry_wait);
  }

  stored_buf=(cherry_current_buffer + 1) & 1;
  if (cherry_card_data_cnt[stored_buf]==0) {
    return 0;
  }

  slen=cherry_card_data_cnt[stored_buf];
  if (count < slen) {
    printk(KERN_INFO "cherry: too few bytes in user buffer\n");
    return -EINVAL;
  }

  if (!access_ok(VERIFY_READ, buf, slen)) {
    printk("kbdr_read: access_ok failed\n");
    return -EFAULT;
  }

  if (__copy_to_user(buf,
		     cherry_card_data_ptr[stored_buf],
		     slen)!=0) {
    return -EFAULT;
  }
  cherry_card_data_cnt[stored_buf]=0;
  cherry_eof_met=1;

  printk(KERN_INFO "cherry: card data sent.\n");

  return slen;
}



static ssize_t cherry_write(struct file *f, const char *buf,
			    size_t count, loff_t *offs) {
  if (!cherry_isopen) {
    return -EINVAL;
  }

  printk(KERN_INFO "Writing not yet supported\n");
  return -EINVAL;
}






/* ________________________________________________________________________
 * AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
 *                          Module init/fini
 * YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
 */



static struct file_operations cherry_file_operations = {
  .owner   = THIS_MODULE,
  .read    = cherry_read,
  .write   = cherry_write,
  .open    = cherry_open,
  .release = cherry_close
};



static struct input_device_id cherry_ids[] = {
{
  .flags = INPUT_DEVICE_ID_MATCH_EVBIT,
  .evbit = { BIT(EV_KEY) },
},

{
  .flags = INPUT_DEVICE_ID_MATCH_EVBIT,
  .evbit = { BIT(EV_MSC) },
},
{ },    /* Terminating entry */
};



static struct input_handler cherry_handler = {
  .event        = cherry_event,
  .connect	= cherry_connect,
  .disconnect	= cherry_disconnect,
  .name		= "cherry",
  .id_table	= cherry_ids,
};



int init_module(void){
  int ret;
  int i;

  printk(KERN_INFO "cherry: loading module\n");
  cherry_state = 0;

  ret = register_chrdev(major, "cherry_io", &cherry_file_operations);
  if (major == 0){
    if (ret > 0){
      printk(KERN_INFO
	     "cherry: registered device cherry_io with major number %d\n", ret);
      major=ret;
    }
    else {
      printk(KERN_INFO
	     "cherry: can't register device cherry_io (auto-major)\n");
      return(-EIO);
    }
  }
  else {
    if (ret) {
      printk(KERN_INFO
	     "cherry: can't register device cherry_io with major number %d\n", major);
      return(-EIO);
    }
    else {
      printk(KERN_INFO
	     "cherry: registered device cherry_io with major number %d\n",
	     major);
    }
  }

  init_waitqueue_head(&cherry_wait);

  printk(KERN_INFO
	 "cherry driver loaded\n");

  /* register our device */
  cherry_dev=input_allocate_device();
  if (cherry_dev==0) {
    printk(KERN_INFO
	   "cherry: Not enough memory to allocate device\n");
    return(-EIO);
  }
  set_bit(EV_KEY, cherry_dev->evbit);
  set_bit(EV_MSC, cherry_dev->evbit);
  set_bit(EV_REP, cherry_dev->evbit);
  //cherry_dev.event = cherry_event;
  cherry_dev->name = DEVICE_DESC;
  //cherry_dev.phys = cherry_phys;
  cherry_dev->id.bustype = BUS_ISA;
  cherry_dev->id.vendor = 0x0000;
  cherry_dev->id.product = 0x0000;
  cherry_dev->id.version = 0x0100;
  for (i = KEY_RESERVED; i < KEY_UNKNOWN; i++)
    set_bit(i, cherry_dev->keybit);

  input_register_device(cherry_dev);

  input_register_handler(&cherry_handler);
  handler_registered=1;
  printk(KERN_INFO
	 "cherry input driver registered\n");

  return 0;
}



void cleanup_module(void){
  input_unregister_handler(&cherry_handler);
  handler_registered=0;
  if (cherry_dev)
    input_unregister_device(cherry_dev);
  if (unregister_chrdev(major, "cherry_io") != 0 ) {
    printk(KERN_INFO "cherry: can't unregister, device busy\n");
  }
  else {
    printk(KERN_INFO "cherry driver unloaded\n");
  }
}








